@@ -247,14 +247,15 @@ class Collection():
         rows = self.rows.iloc[list(row_indices)]
         return rows
 
-    def get_image_urls(self, rows, source=0, generate_signed_urls=False, override_imageset_id=None):
+    def get_image_urls(self, rows, source=0, generate_signed_urls=False,
+                       signed_expiry_days=None, override_imageset_id=None):
         """Converts rows into their corresponding image URLs.
 
         If generate_signed_urls is false the URLs require a token to download
         These urls can be passed to download_image()/download_image_batch().
 
         If generate_signed_urls is true the urls can be used to fetch the images directly
-        from blob storage, using a temporary access signature.
+        from blob storage, using a temporary access signature with an optionally specified lifetime.
 
         By default the uploaded images are fetched, but it's possible to fech e.g. the thumbnails
         only, by providing an alternative imageset id.
@@ -286,9 +287,12 @@ class Collection():
                 c.HOME, c.API_0, self.workspace_id, imageset_id,
                 i) for i in imageset_indices]
         else:
-            get_signed_urls = ['{}/{}/project/{}/imagesets/{}/images/{}/signed_route'.format(
+            query = ''
+            if signed_expiry_days is not None:
+                query = '?expiry_days={}'.format(signed_expiry_days)
+            get_signed_urls = ['{}/{}/project/{}/imagesets/{}/images/{}/signed_route{}'.format(
                 c.HOME, c.API_0, self.workspace_id, imageset_id,
-                i
+                i, query
             ) for i in imageset_indices]
             signed_route_urls = []
             for url in get_signed_urls:
